@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.547";
+our $VERSION = "0.548";
 
 1;
 
@@ -72,7 +72,7 @@ The open mode $open_mode is replaced to a representation of the L<fopen|https://
   +>             w+b
   +>>            a+b
 
-If the system supports C<FD_CLOEXEC>, this flag is set to the opened file's file descriptor using L</"fcntl">.
+If the system supports C<FD_CLOEXEC>, this flag is set to the opened file descriptor using L</"fcntl">.
 
 Exceptions:
 
@@ -256,13 +256,17 @@ Exceptions thrown by L<Sys::IO#ftell|SPVM::Sys::IO/"ftell"> method could be thro
 
 =head2 sysopen
 
-C<static method sysopen : void ($fd_ref : int*, $file : string, $flags : int, $mode : int = 0);>
+C<static method sysopen : void ($fd_ref : int*, $file : string, $int_mode : int, $perms : int = -1);>
 
-Opens a file given, the file path $file, the mode $flags and the mode $mode.
+Opens a file given, the file path $file, the integer open mode $int_mode and the permissions $perms.
 
 The file descriptor of the opened file is set to the value reffered by $fd_ref.
 
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to the flags $flags and the mode $mode.
+If $perms is a negative value, it is set to C<0644 & ~Sys->umask>.
+
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to the flags $int_mode and the mode $perms.
+
+If the system supports C<FD_CLOEXEC>, this flag is set to the opened file descriptor using L</"fcntl">.
 
 Exceptions:
 
@@ -340,9 +344,11 @@ Exceptions thrown by L<Sys::IO#mkdir|SPVM::Sys::IO/"mkdir"> method could be thro
 
 =head2 umask
 
-C<static method umask : int ($mode : int);>
+C<static method umask : int ($perms : int = -1);>
 
-Sets the umask for the process to the mode $mode and returns the previous value.
+Sets the umask for the process to the mode $perms and returns the previous value.
+
+If $perms is a negative value, this method returns the current umask permission without setting.
 
 Exceptions:
 
@@ -548,8 +554,6 @@ The open mode $open_mode is replaced to a representation of the L<fopen|https://
   |-             wb
   -|             rb
 
-If the system supports C<FD_CLOEXEC>, this flag is set to the opened file's file descriptor using L</"fcntl">.
-
 Exceptions:
 
 Exceptions thrown by L<Sys::IO#popen|SPVM::Sys::IO/"popen"> method or L<Sys::IO#_popen|SPVM::Sys::IO/"_popen"> method could be thrown.
@@ -1240,8 +1244,6 @@ The opened writing file descripor is set to the value referenced by $socket_fd2_
 
 This method calls L<Sys::Socket#socketpair|SPVM::Sys::Socket/"socketpair"> method .
 
-If available, C<FD_CLOEXEC> is set to the file descriptor of the value referenced by $socket_fd1_ref and the value referenced by $socket_fd2_ref.
-
 Exceptions:
 
 Exceptions thrown by L<Sys::Socket#socketpair|SPVM::Sys::Socket/"socketpair"> method could be thrown.
@@ -1435,8 +1437,6 @@ C<static method pipe : void ($read_fd_ref : int*, $write_fd_ref : int*);>
 
 Opens a pair of pipes.
 
-If the system supports C<FD_CLOEXEC>, this flag is set to the value referenced by $read_fd_ref and the value referenced by $write_fd_ref using L</"fcntl">.
-
 =head2 getpgrp
 
 C<static method getpgrp : int ($process_id : int);>
